#/usr/bin/env python
# Works with both 2.x and 3.x versions of Python.

# pound comment

import time
print('Hello.  The time is %f Unix epoch.' % (time.time()))  # inline comment

"""
Docstring,
  also counted as comment.
"""



#/usr/bin/env python

# pound comment

import time
print('Hello.  The time is %f Unix epoch.' % (time.time()))  # inline comment
print(f'f-string')

"""
Docstring,
  also counted as comment.
"""

'''
Single
  Quoted
    Docstring'''



#!/usr/bin/env python
import numpy as np

from pylab import gca

labels = ["Baseline", "System"]
data =   [3.75               , 4.75]
error =  [0.3497             , 0.3108]

xlocations = na.array(range(len(data)))+0.5
width = 0.6
# bar chart with hollow bars:
bar(xlocations, data, yerr=error, width=width, edgecolor='k', facecolor='none')
yticks(range(0, 8))
xticks(xlocations+ width/2, labels)
xlim(0, xlocations[-1]+width*2)
title("Average Ratings on the Training Set")
gca().get_xaxis().tick_bottom()
gca().get_yaxis().tick_left()

show()



import glob
import numpy as np

def print_info(path)
    '''
    print stuff
    '''
    files = sorted(glob.glob('%s/*.*' % path))
    for i, file in enumerate(files):
        labels = np.loadtxt(file, dtype=np.float32).reshape(-1, 5)
        x += np.bincount(labels[:, 0].astype('int32'), minlength=nc)
        print(i, len(files))

'''
end stuff
'''



"""
This is a docstring.
"""

def abc(d,
        a11):
    ''' this is a docstring '''
    d = 2
    a = """
    this is not
    a docstring
    """
    def xyz(d):
        """
        this is a docstring
        """
        x = 1
        a = """ this is not a docstring
        """

class Abc():
    ''' this is a docstring '''
    d = 2
    a = """
    this is not
    a docstring
    """
    def Xyz(d):
        """
        this is a docstring
        """
        x = 1
        a = """
        this is not a docstring """

